## lightweight-charts-server

[lightweight-charts-python](https://github.com/louisnw01/lightweight-charts-python) based chart hosting library

### Installation

```
pip install --upgrade lightweight-charts-server
```


### Examples

Examples of usage are in [examples/](examples/)

**Get examples through git clone**
```
git clone https://github.com/vegaxholdings/lightweight-charts-server.git

cd lightweight-charts-server

pip install -r requirements.txt
```

**Run Examples**
1. `python -m examples.1_setting_data.setting_data`  
2. `python -m examples.2_live_data.live_data`  
3. `python -m examples.3_tick_data.tick_data`  
4. `python -m examples.4_line_indicators.line_indicators`  
5. `python -m examples.5_styling.styling`  